==> haskell-patience-0.1.1-7-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-patience.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: patience
version: 0.1.1
id: patience-0.1.1-ByieOh635rzAIvJxHEy8CG
key: patience-0.1.1-ByieOh635rzAIvJxHEy8CG
license: BSD-3-Clause
maintainer: Keegan McAllister <mcallister.keegan@gmail.com>
author: Keegan McAllister <mcallister.keegan@gmail.com>
synopsis: Patience diff and longest increasing subsequence
description:
    This library implements the \"patience diff\" algorithm, as well as the patience
    algorithm for the longest increasing subsequence problem.
    .
    Patience diff computes the difference between two lists, for example the
    lines of two versions of a source file.  It provides a good balance of
    performance, nice output for humans, and implementation simplicity.  For more
    information, see <http://alfedenzo.livejournal.com/170301.html> and
    <http://bramcohen.livejournal.com/73318.html>.
    .
    New in version 0.1.1: relaxed @containers@ dependency, so it should build on
    GHC 6.10.
category: Algorithms, Text
abi: 3fdb9ea14b83c174b7bd3d1030eba3ca
exposed: True
exposed-modules:
    Data.Algorithm.Patience
import-dirs: /usr/lib/ghc-8.4.3/site-local/patience-0.1.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/patience-0.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/patience-0.1.1
hs-libraries: HSpatience-0.1.1-ByieOh635rzAIvJxHEy8CG
depends:
    base-4.11.1.0 containers-0.5.11.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
haddock-interfaces: /usr/share/doc/haskell-patience/html/patience.haddock
haddock-html: /usr/share/doc/haskell-patience/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-patience-0.1.1-8-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-patience.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: patience
version: 0.1.1
id: patience-0.1.1-FWHLjMdEKfZ4SBowtfguxa
key: patience-0.1.1-FWHLjMdEKfZ4SBowtfguxa
license: BSD-3-Clause
maintainer: Keegan McAllister <mcallister.keegan@gmail.com>
author: Keegan McAllister <mcallister.keegan@gmail.com>
synopsis: Patience diff and longest increasing subsequence
description:
    This library implements the \"patience diff\" algorithm, as well as the patience
    algorithm for the longest increasing subsequence problem.
    .
    Patience diff computes the difference between two lists, for example the
    lines of two versions of a source file.  It provides a good balance of
    performance, nice output for humans, and implementation simplicity.  For more
    information, see <http://alfedenzo.livejournal.com/170301.html> and
    <http://bramcohen.livejournal.com/73318.html>.
    .
    New in version 0.1.1: relaxed @containers@ dependency, so it should build on
    GHC 6.10.
category: Algorithms, Text
abi: 9279762737d2dd7cb461263f4d550110
exposed: True
exposed-modules:
    Data.Algorithm.Patience
import-dirs: /usr/lib/ghc-8.6.1/site-local/patience-0.1.1
library-dirs: /usr/lib/ghc-8.6.1/site-local/patience-0.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.6.1/patience-0.1.1
hs-libraries: HSpatience-0.1.1-FWHLjMdEKfZ4SBowtfguxa
depends:
    base-4.12.0.0 containers-0.6.0.1
haddock-interfaces: /usr/share/doc/haskell-patience/html/patience.haddock
haddock-html: /usr/share/doc/haskell-patience/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
